// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package alarm

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jinzhu/gorm"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
	"fmt"
	"smart-government-management/utils"
)



func AlarmHandle(ctx context.Context, req *v1.AlarmHandleRequest) (reply *v1.AlarmHandleReply, err error) {
	if req.Id < 1 {
		return nil, errors.ParamsError
	}
	p := model.TAlarm{}
	reply = &v1.AlarmHandleReply{
	}
	where := map[string]interface{}{
		"id":req.Id,
	}
	err = p.Query(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.NoRecordError
	}
	values := map[string]interface{}{
		"is_handle":req.Handle,
	}

	where = map[string]interface{}{
		"alarm_code":p.AlarmCode,
		"device_code":p.DeviceCode,
		"sn":p.Sn,
		"is_handle":false,
	}
	p = model.TAlarm{}

	// 分布式锁，告警端同样需增加分布式锁
	key := fmt.Sprintf("%s-%s-%d", p.Sn, p.AlarmCode, p.DeviceCode)
	ok, err := utils.RedisLock(key, 500, 10)
	if err != nil {
		return nil, err
	}
	if !ok {
		return nil, errors.SystemError
	}
	defer utils.RedisUnlock(key)

	err = p.Update(database.DB(), where, values)
	if err != nil {
		return nil, errors.DataBaseError
	}
	return reply, nil
}
