// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package alarm

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
)

func AlarmList(ctx context.Context, req *v1.AlarmListRequest) (reply *v1.AlarmListReply, err error) {
	if req.Page < 1 {
		req.Page = 1
	}
	if req.PageSize == 0 {
		req.PageSize = 10
	}

	pt := &model.TDeviceTypeItem{}
	m, _, err := pt.AllMap(database.DB())
	if err != nil {
		logger.Error("DeviceList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	p := model.TAlarm{}
	reply = &v1.AlarmListReply{
		Page:req.Page,
		PageSize:req.PageSize,
	}

	dreq := model.AlarmListRequest{
		Start:req.Start,
		End:req.End,
		ProjectId:req.ProjectId,
		IsHandle:req.IsHandle,
		Page:req.Page,
		PageSize:req.PageSize,
		Filter:req.Filter,
		DeviceCode:req.DeviceCode,

	}

	list, total, err := p.ListMore(database.DB(), &dreq)
	if err != nil {
		logger.Error("AlarmList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	reply.Total = total
	reply.HasMore = false
	if total == 0 {
		return reply, nil
	}

	reply.List = make([]*v1.AlarmItem, len(list))
	for i, v := range list {
		item := &v1.AlarmItem{}
		item.Sn = v.Sn
		item.Time = v.Time.Format("2006-01-02 15:04:05")
		item.Reason = v.AlarmReason
		item.IsHandled = v.IsHandle
		item.Name = v.Name
		item.TypeName = m[v.DeviceCode]
		item.Id = v.Id
		item.ProjectName = v.ProjectName
		item.ProjectId = v.ProjectId
		item.SafetyRecordNo = v.SafetyRecordNo
		reply.List[i] = item
	}
	if int64(reply.Page - 1) * int64(reply.PageSize) + int64(len(reply.List)) < reply.Total {
		reply.HasMore = true
	}
	return reply, nil
}
