// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package alarm

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
	"strconv"
)

func AlarmReasonStatistic(ctx context.Context, req *v1.AlarmReasonStatisticRequest) (reply *v1.AlarmReasonStatisticReply, err error) {

	list, err := model.AlarmReasonStatistic(database.DB())
	if err != nil {
		return nil, errors.DataBaseError
	}

	reply = &v1.AlarmReasonStatisticReply{}
	reply.List = make([]*v1.AlarmReasonStatisticItem, len(list))
	total := int64(0)
	handled := int64(0)
	for _, v := range list {
		total += v.Total
		handled += v.Handled
	}
	for i, v := range list {
		item := &v1.AlarmReasonStatisticItem{
			Total:v.Total,
			Handled:v.Handled,
			Reason: v.Reason,
		}
		if v.Total == 0 || total == 0{
			item.TotalPercent = "0.00%"
		} else {
			item.TotalPercent = strconv.FormatFloat(float64(v.Total*100)/float64(total), 'f', 2, 64)+"%"
		}

		if v.Handled == 0 || handled == 0{
			item.HandledPercent = "0.00%"
		} else {
			item.HandledPercent = strconv.FormatFloat(float64(v.Handled*100)/float64(handled), 'f', 2, 64)+"%"
		}
		reply.List[i] = item
	}
	reply.Handled = handled
	reply.Total = total
	return reply, nil
}
