// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package alarm

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
	"strconv"
	"time"
)

func formatFloat(data float64) float64 {
	s := strconv.FormatFloat(data, 'f', 2, 64)
	ret, _ := strconv.ParseFloat(s, 64)
	return ret
}

func get30Days()(time.Time, time.Time){
	now := time.Now()
	now = time.Date(now.Year(), now.Month(), now.Day(), 0, 0, 0, 0, now.Location())
	end := time.Now().Add(24*time.Hour)
	start := now.Add(-29*24*time.Hour)
	return start, end

}

// 返回最近30天的处理趋势和告警趋势
func AlarmPercentStatistic(ctx context.Context, req *v1.AlarmPercentStatisticRequest) (reply *v1.AlarmPercentStatisticReply, err error) {

	start, end := get30Days()
	list, err := model.AlarmPercentStatistic(database.DB(), start.Format("2006-01-02"), end.Format("2006-01-02"))
	if err != nil {
		return nil, errors.DataBaseError
	}

	// 根据日期构造map
	m := map[string]model.AlarmPercentStatisticItem{}
	for _, v := range list {
		m[v.Date.Format("2006-01-02")] = v
	}

	reply = &v1.AlarmPercentStatisticReply{}
	reply.List = make([]*v1.AlarmPercentStaticticItem, 30)
	for i := 0; i < 30; i++ {
		date := start.Add(time.Duration(i*24)*time.Hour).Format("2006-01-02")
		item := v1.AlarmPercentStaticticItem{}
		item.Date = date
		if v, ok := m[date]; ok {
			item.HandledCount =v.HandleCount
			item.AlarmCount = v.Count
		}

		if item.AlarmCount > 0 {
			item.HandledPercent = formatFloat(float64(item.HandledCount)/float64(item.AlarmCount))
		} else {
			item.HandledPercent = formatFloat(1.00)
		}
		reply.Total += item.AlarmCount
		reply.List[i] = &item
	}

	for i, v := range reply.List {
		if reply.Total ==  0 {
			break
		}
		reply.List[i].AlarmPercent = formatFloat(float64(v.AlarmCount)/float64(reply.Total))
	}

	return reply, nil
}
