// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package alarm

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
	"strconv"
)

func AlarmProject(ctx context.Context, req *v1.AlarmProjectRequest) (reply *v1.AlarmProjectReply, err error) {

	list, err := model.AlarmProjectStatistic(database.DB())
	if err != nil {
		return nil, errors.DataBaseError
	}

	reply = &v1.AlarmProjectReply{}
	reply.List = make([]*v1.AlarmProjectItem, len(list))
	for i, v := range list {
		item := &v1.AlarmProjectItem{
			Total:v.Total,
			Handled:v.Handled,
			ProjectId:v.ProjectId,
			ProjectName:v.ProjectName,
		}
		if v.Total == 0 || v.Handled == 0{
			item.Percent = "0.00%"
		} else {
			item.Percent = strconv.FormatFloat(float64(v.Handled*100)/float64(v.Total), 'f', 2, 64)+"%"
		}
		reply.List[i] = item
	}
	return reply, nil
}
