// Copyright 2019  githup.com. All rights reserved.
// Use of this source code is governed by  githup.com.
package company

import (
	"context"
	"encoding/base64"
	"encoding/json"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/transtasker"
	"github.com/jaryhe/gopkgs/util"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
	"smart-government-management/consts"
	"smart-government-management/errors"
	dbmodel "smart-government-management/model"
	"smart-government-management/pb"
	pb_v1 "smart-government-management/pb/v1"
	"time"
)

const (
	// 0 企业入驻审批 1 项目入驻审批 2 项目变更审批
	ApproveTypeCompany = iota
	ApproveTypeProject
	ApproveTypeProjectChange
)

const CRYPTO_KEY = "3D28BP43U3Y1B4N6REQW3F319DD23467"

func getB64Pass(passwd string) (string, error) {
	cryPasswd, err := util.AesEncrypt(passwd, CRYPTO_KEY)
	if err != nil {
		return "", errors.ParamsError
	}
	ret := base64.StdEncoding.EncodeToString(cryPasswd)
	return ret, nil
}

func getMd5Pass(passwd string) (string, error) {
	cryPasswd, err := util.AesEncrypt(passwd, CRYPTO_KEY)
	if err != nil {
		return "", errors.ParamsError
	}
	ret := util.MD5(base64.StdEncoding.EncodeToString(cryPasswd))
	return ret, nil
}

func getOriginPass(passwd string) string {
	bytes, _ := base64.StdEncoding.DecodeString(passwd)
	ret, _ := util.AesDecrypt(bytes, []byte(CRYPTO_KEY))
	return string(ret)
}

func companyApprove(req *pb_v1.CompanyApproveRequest) (reply *pb_v1.CompanyApproveReply, err error) {
	p := &dbmodel.TCompany{}
	where := map[string]interface{}{
		"id": req.Id,
	}
	// 状态判断
	err = p.Find(database.DB(), where, nil)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("companyApprove",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.NoRecordError
	}
	if p.Status != consts.CompanyStatusAddAuditting {
		return nil, errors.CanNotApproveWithStatus
	}

	// 更新
	where = map[string]interface{}{
		"id":     req.Id,
		"status": consts.CompanyStatusAddAuditting,
	}
	value := map[string]interface{}{
		"status":       consts.CompanyStatusAddAuditted,
		"approve_time": time.Now(),
		"feedback":     req.Feedback,
	}
	if !req.Status {
		value["status"] = consts.CompanyStatusAddAudittedFail
	}
	err = p.Update(database.DB(), where, value)
	if err != nil {
		logger.Error("companyApprove",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	go func() {
		mreq := pb_v1.SendThroughVerifyRequest{
			Company:     p.Name,
			CompanyType: 2,
			PhoneNumber: p.BusinessContactPhone,
			Status:      req.Status,
			ApproveTime: time.Now().Format("2006-01-02 15:04:05"),
		}
		pb.Thirdparty.SendThroughVerify(context.Background(), &mreq)
	}()

	return &pb_v1.CompanyApproveReply{}, nil
}

/*
func projectAddApprove(req *pb_v1.CompanyApproveRequest)(reply *pb_v1.CompanyApproveReply, err error) {
	p := &dbmodel.TProject{}
	where := map[string]interface{}{
		"id":req.Id,
	}
	// 状态判断
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("projectAddApprove",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.NoRecordError
	}
	if p.Status != consts.ProjectStatusAddAuditting {
		return nil, errors.CanNotApproveWithStatus
	}

	// 更新
	where = map[string]interface{}{
		"id":req.Id,
		"status":consts.ProjectStatusAddAuditting,
	}
	value := map[string]interface{}{
		"status":consts.ProjectStatusAddAuditted,
		"approve_time":time.Now(),
	}
	if !req.Status {
		value["status"] = consts.ProjectStatusAddAudittedFail
	}
	updateTask := func(db *gorm.DB) error {
		err = p.Update(db, where, value)
		if err != nil {
			logger.Error("projectAddApprove",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}
		return nil
	}
	now := time.Now()
	createProjectUserTask := func(db *gorm.DB) error {
		// 建设单位账号
		p := dbmodel.TSiteUser{
			Username:"constructer",
			UserType:1,
			CreatedAt:now,
			UpdatedAt:now,
			Enable:true,
			ProjectId:req.Id,
			SiteUser:0,
		}
		p.Passwd,_ = getB64Pass("constructer")
		err = p.Insert(db)
		if err != nil {
			logger.Error("projectAddApprove",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}

		// 项目部账号
		p.Id = 0
		p.Username = "project"
		p.Passwd,_ = getB64Pass("project")
		p.SiteUser = 1
		p.UserType = 2
		err = p.Insert(db)
		if err != nil {
			logger.Error("projectAddApprove",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}

		// 监理部账号
		p.Id = 0
		p.Username = "supervisor"
		p.Passwd,_ = getB64Pass("supervisor")
		p.SiteUser = 0
		p.UserType = 3
		err = p.Insert(db)
		if err != nil {
			logger.Error("projectAddApprove",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}

		return nil
	}

	err = transtasker.Exec(database.DB(),
		transtasker.NewTask(updateTask),
		transtasker.NewTask(createProjectUserTask))

	return &pb_v1.CompanyApproveReply{}, nil
}
*/
func projectChangeApprove(req *pb_v1.CompanyApproveRequest) (reply *pb_v1.CompanyApproveReply, err error) {
	p := &dbmodel.TProjectJob{}
	where := map[string]interface{}{
		"id": req.Id,
	}
	// 状态判断
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("projectChangeApprove",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.NoRecordError
	}
	if p.Status != 0 {
		return nil, errors.CanNotApproveWithStatus
	}

	content := ""
	jobTask := func(db *gorm.DB) error {
		job := &dbmodel.TProjectJob{}
		where := map[string]interface{}{
			"id": req.Id,
		}
		status := 2
		if req.Status {
			status = 1
		}
		value := map[string]interface{}{
			"feedback":   req.Feedback,
			"status":     status,
			"updated_at": time.Now(),
		}
		err := job.Update(db, where, value)
		if err != nil {
			logger.Error("projectChangeApprove",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}
		content = p.Content

		return nil
	}

	changeTask := func(db *gorm.DB) error {
		where = map[string]interface{}{
			"id": p.ProjectId,
		}
		m := map[string]interface{}{}
		err = json.Unmarshal([]byte(content), &m)
		if err != nil {
			return errors.SystemError
		}
		project := dbmodel.TProject{}
		err = project.Update(db, where, m)
		if err != nil {
			logger.Error("projectChangeApprove",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}
		return nil
	}

	err = transtasker.Exec(database.DB(),
		transtasker.NewTask(jobTask),
		transtasker.NewTask(changeTask))

	// 更新

	return &pb_v1.CompanyApproveReply{ProjectId: p.ProjectId}, err
}

func CompanyApprove(ctx context.Context, req *pb_v1.CompanyApproveRequest) (reply *pb_v1.CompanyApproveReply, err error) {
	switch req.ApproveType {
	case ApproveTypeCompany:
		return companyApprove(req)
	case ApproveTypeProject:
		//return projectAddApprove(req)
	case ApproveTypeProjectChange:
		return projectChangeApprove(req)
	}
	return nil, errors.ParamsError
}
