// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package company

import (
	"fmt"
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jinzhu/gorm"
	"strings"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)



func CompanyList(ctx context.Context, req *v1.CompanyListRequest) (reply *v1.CompanyListReply, err error) {
	p := model.TCompany{}

	and := map[string]interface{}{}
	or := map[string]interface{}{}

	if req.Filter != "" {
		or["name like"] = fmt.Sprintf("%%%s%%", req.Filter)
		or["social_code like"] = fmt.Sprintf("%%%s%%", req.Filter)
	}
	if len(req.FilterStatus) > 0 {
		and["status in"] = req.FilterStatus
	}
	total, err := p.Count(database.DB(), and, or)
	if err != nil {
		logger.Error("CompanyList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	reply = &v1.CompanyListReply{
		Total:total,
		Page:req.Page,
		PageSize:int32(model.PageSize),
	}
	if total == 0 {
		return reply, nil
	}
	list, err := p.List(database.DB(), and, or, req.Page)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("CompanyList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	reply.List = make([]*v1.CompanyItem, len(list))
	for i, v := range list {
		reply.List[i] = &v1.CompanyItem{}
		reply.List[i].Status = v.Status
		reply.List[i].ApplyTime = v.CreatedAt.Format(layout)
		if v.Status > 0 {
			reply.List[i].ApproveTime = v.ApproveTime.Format(layout)
		}
		reply.List[i].Name = v.Name
		reply.List[i].SocialCode = v.SocialCode
		reply.List[i].Id = v.Id
		reply.List[i].BusinessContactPhone = v.BusinessContactPhone
		reply.List[i].BusinessContact = v.BusinessContact
		reply.List[i].Province = v.Province
		reply.List[i].City = v.City
		reply.List[i].Zone = v.Zone
		reply.List[i].Feedback =v.Feedback
		reply.List[i].LegalPerson = v.LegalPerson
		reply.List[i].UserName = v.UserName
		reply.List[i].BusinessResponsible = v.BusinessResponsible
		reply.List[i].BusinessResponsiblePhone = v.BusinessResponsiblePhone
		reply.List[i].IdCert = v.IdCert
		reply.List[i].EmergencyContact = v.EmergencyContact
		reply.List[i].EmergencyContactPhone = v.EmergencyContactPhone
		reply.List[i].BusinessLicense = v.BusinessLicense
		if !strings.Contains(v.BusinessLicense, "[") {
			reply.List[i].BusinessLicense = "[]"
		}
	}

	return reply, nil
}
