// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package company

import (
	"fmt"
	"context"
	"encoding/json"
	"github.com/jaryhe/gopkgs/database"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)
var projectFieldMap = map[string]string{
	"safety_record_no":"安监备案号",
	"project_no":"项目编号",
	"name":"项目名称",
	"short_name":"项目简称",
	"project_function":"项目功能",
	"project_type":"项目类型",
	"price":"项目造价",
	"desc":"项目介绍",
	"project_leader":"项目负责人",
	"covered_area":"建筑面积",
	"phone":"项目负责人电话",
	"total_level":"总层数",
	"building_storey":"建筑层数",
	"construction":"施工单位",
	"development":"建设单位",
	"oversee":"监理单位",
	"design":"设计单位",
	"exploration":"勘察单位",
	"location":"地址",
	"lon":"经度",
	"lat":"纬度",
	"is_finish":"是否完工",
}

var projectFieldTypeMap = map[string]string{
	"id":               "int",
	"cid":              "int",
	"safety_record_no": "string",
	"project_no":       "string",
	"name":             "string",
	"short_name":       "string",
	"project_function": "string",
	"project_type":     "string",
	"price":            "float",
	"desc":             "string",
	"project_leader":   "string",
	"covered_area":     "string",
	"phone":            "string",
	"total_level":      "string",
	"building_storey":  "string",
	"construction":     "string",
	"development":      "string",
	"oversee":          "string",
	"design":           "string",
	"exploration":      "string",
	"location":         "string",
	"lon":              "float",
	"lat":              "float",
	"is_finish":        "int",
}

func makeProjectChangeInfoContent(data []byte)([]*v1.ProjectInfoItem) {
	m := map[string]interface{}{}
	if len(data) == 0 {
		return nil
	}
	json.Unmarshal(data, &m)
	ret := make([]*v1.ProjectInfoItem, len(m))
	i := 0
	for k, v := range m {
		item := &v1.ProjectInfoItem{
			Name:k,
			Chinese:projectFieldMap[k],
			Value:fmt.Sprintf("%v", v),
		}
		ret[i] = item
		i++
	}
	return ret
}

func ProjectChangeInfoList(ctx context.Context, req *v1.ProjectChangeInfoListRequest) (reply *v1.ProjectChangeInfoListReply, err error) {
	p := model.TProjectJob{}
	list, total, err := p.ProjectChangeList(database.DB(), req.Page, req.Filter, req.FilterStatus)
	if err != nil {
		logger.Error("ProjectChangeInfoList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	reply = &v1.ProjectChangeInfoListReply{
		Total:total,
		Page:req.Page,
		PageSize:int32(model.PageSize),
	}
	if total == 0 {
		return reply, nil
	}

	reply.List = make([]*v1.ProjectChangeInfoItem, len(list))
	for i, v := range list {
		reply.List[i] = &v1.ProjectChangeInfoItem{}
		reply.List[i].Id = v.Id
		reply.List[i].Status = v.Status
		reply.List[i].ApplyTime = v.ApplyTime.Format(layout)
		if v.Status > 0 {
			reply.List[i].ApproveTime = v.ApproveTime.Format(layout)
		}
		reply.List[i].Origin = makeProjectChangeInfoContent([]byte(v.Origin))
		reply.List[i].Dst = makeProjectChangeInfoContent([]byte(v.Content))
		reply.List[i].Name = v.ProjectName
		reply.List[i].SafetyRecordNo = v.SafetyRecordNo
		reply.List[i].Addr = v.Addr
		reply.List[i].CompanyName = v.CompanyName
	}

	return reply, nil
}
