// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package company

import (
	"context"
	"fmt"
	"smart-government-management/errors"
	"smart-government-management/model"
	"smart-government-management/pb/v1"
	"strings"

	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
)

var layout = "2006-01-02 15:04:05"

func ProjectList(ctx context.Context, req *v1.ProjectListRequest) (reply *v1.ProjectListReply, err error) {
	and := map[string]interface{}{}
	or := map[string]interface{}{}
	if req.Filter != "" {
		or["name like"] = fmt.Sprintf("%%%s%%", req.Filter)
		or["location like"] = fmt.Sprintf("%%%s%%", req.Filter)
		or["safety_record_no like"] = fmt.Sprintf("%%%s%%", req.Filter)
	}
	p := model.TProject{}
	total, err := p.Count(database.DB(), and, or)
	if err != nil {
		logger.Error("ProjectList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if req.Page == 0 {
		req.Page = 1
	}
	if req.PageSize == 0 {
		req.PageSize = model.PageSize
	}
	reply = &v1.ProjectListReply{
		Total:    total,
		PageSize: int32(model.PageSize),
		Page:     req.Page,
	}
	if total == 0 {
		return reply, nil
	}
	list, err := p.ListWithCompay(database.DB(), req.Filter, req.Page, req.PageSize)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("ProjectList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	reply.List = make([]*v1.ProjectItem, len(list))
	for i, v := range list {
		reply.List[i] = &v1.ProjectItem{}
		reply.List[i].Id = v.Id
		reply.List[i].Location = v.Location
		reply.List[i].Name = v.Name
		reply.List[i].Phone = v.Phone
		reply.List[i].SafetyRecordNo = v.SafetyRecordNo
		reply.List[i].ProjectLeader = v.ProjectLeader

		reply.List[i].ProjectNo = v.ProjectNo
		reply.List[i].Lon = v.Lon
		reply.List[i].Lat = v.Lat
		reply.List[i].Price = v.Price
		reply.List[i].BuildingStorey = v.BuildingStorey
		reply.List[i].Construction = v.Construction
		reply.List[i].CoveredArea = v.CoveredArea
		reply.List[i].Desc = v.Desc
		reply.List[i].Design = v.Design
		reply.List[i].Development = v.Development
		reply.List[i].Exploration = v.Exploration
		reply.List[i].Oversee = v.Oversee
		reply.List[i].ProjectFunction = v.ProjectFunction
		reply.List[i].ProjectPlan = v.ProjectPlan
		reply.List[i].ProjectType = v.ProjectType
		reply.List[i].TotalLevel = int32(v.TotalLevel)
		if v.IsFinish > 0 {
			reply.List[i].IsFinish = true
		}
		reply.List[i].CompanyName = v.CompanyName
		reply.List[i].CreateTime = v.CreatedAt.Format(layout)
		reply.List[i].StartDay = strings.Split(v.StartDay, "T")[0]
		reply.List[i].EndDay = strings.Split(v.EndDay, "T")[0]
		if v.ProjectPlan == "" {
			reply.List[i].ProjectPlan = "[]"
		}
	}

	return reply, nil
}
