// Copyright 2019  githup.com. All rights reserved.
// Use of this source code is governed by  githup.com.
package user

import (
	"context"
	"encoding/base64"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/util"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
	"smart-government-management/errors"
	dbmodel "smart-government-management/model"
	pb_v1 "smart-government-management/pb/v1"
	"time"
)

const CRYPTO_KEY = "3D28BP43U3Y1B4N6REQW3F319DD23464"

func getMd5Pass(passwd string) (string, error) {
	cryPasswd, err := util.AesEncrypt(passwd, CRYPTO_KEY)
	if err != nil {
		return "", errors.ParamsError
	}
	ret := util.MD5(base64.StdEncoding.EncodeToString(cryPasswd))
	return ret, nil
}

func Login(ctx context.Context, req *pb_v1.LoginRequest)(reply *pb_v1.LoginReply, err error) {
	if req.User == "" || req.Password == "" {
		return nil, errors.ParamsError
	}
	p := &dbmodel.TSystemAdmin{}
	where := map[string]interface{}{"name":req.User}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("Login",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.UserNotExistError
	}
	pass,_ := getMd5Pass(req.Password)
	if pass != p.Passwd {
		return nil, errors.UserPassError
	}
	reply = &pb_v1.LoginReply{
		Uid:p.Id,
		Develop:p.Develop,
	}
	return reply, nil
}


func InitDefaultUser() error {
	p := &dbmodel.TSystemAdmin{}
	db := database.DB().Begin()
	total, err := p.Count(db, nil, nil)
	if err != nil {
		db.Rollback()
		return err
	}
	if total > 0 {
		db.Rollback()
		return nil
	}
	now := time.Now()
	p.Name = "admin"
	p.Passwd,_ = getMd5Pass("123456")
	p.CreatedAt = now
	p.UpdatedAt = now
	err = p.Insert(db)
	if err != nil {
		db.Rollback()
		return err
	}

	p.Id = 0
	p.Name = "develop"
	p.Passwd,_ = getMd5Pass("zaq12edc")
	p.CreatedAt = now
	p.UpdatedAt = now
	p.Develop = 1
	err = p.Insert(db)
	if err != nil {
		db.Rollback()
		return err
	}
	db.Commit()
	return nil
}

func ResetAdmin() error {
	p := &dbmodel.TSystemAdmin{}
	db := database.DB()
	where := map[string]interface{}{
		"name": "admin",
	}
	passwd,_ := getMd5Pass("123456")
	value := map[string]interface{}{
		"passwd": passwd,
	}
	p.Update(db, where, value)
	return nil
}

func ResetDevelop() error {
	p := &dbmodel.TSystemAdmin{}
	db := database.DB()
	where := map[string]interface{}{
		"name": "develop",
	}
	passwd,_ := getMd5Pass("zaq12edc")
	value := map[string]interface{}{
		"passwd": passwd,
	}
	p.Update(db, where, value)
	return nil
}
