// Copyright 2019  githup.com. All rights reserved.
// Use of this source code is governed by  githup.com.
package user

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
	"smart-government-management/errors"
	dbmodel "smart-government-management/model"
	pb_v1 "smart-government-management/pb/v1"
	"strings"
)

func SetPhone(ctx context.Context, req *pb_v1.SetPhoneRequest)(reply *pb_v1.SetPhoneReply, err error) {
	if req.Uid == 0 {
		return nil, errors.ParamsError
	}
	p := &dbmodel.TSystemAdmin{}
	where := map[string]interface{}{"id":req.Uid}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("SetPhone",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.UserNotExistError
	}

	if req.Phone == "" {
		err = p.UpdatePhoneNull(database.DB(), req.Uid)
		if err != nil {
			return nil, errors.DataBaseError
		}
		return &pb_v1.SetPhoneReply{}, nil
	}
	value := map[string]interface{}{"phone":req.Phone, "email":req.Email}
	err = p.Update(database.DB(), where, value)
	if err != nil {
		if strings.Contains(err.Error(), "uplicate") {
			return nil, errors.UserExistError
		}
		return nil, errors.DataBaseError
	}
	return &pb_v1.SetPhoneReply{}, nil
}
